==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/PropertyEditorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyEditorDescription } from "./PropertyEditorDescription";
/**
 * @hidden
 */
var PropertyEditorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(PropertyEditorDescriptionMetadata, _super);
    function PropertyEditorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PropertyEditorDescriptionMetadata.b = function (a) {
        if (PropertyEditorDescriptionMetadata.a == null) {
            PropertyEditorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PropertyEditorDescriptionMetadata.c(PropertyEditorDescriptionMetadata.a);
        }
        if (a.j(PropertyEditorDescriptionMetadata.a)) {
            return;
        }
        a.y(PropertyEditorDescriptionMetadata.a);
    };
    PropertyEditorDescriptionMetadata.c = function (a) {
        a.item("ActualDataSource", "(w:ActualProperties,xam:ActualProperties,wf:ActualProperties)Collection:PropertyEditorPropertyDescription:PropertyEditorPropertyDescriptionCollection:PropertyEditorPropertyDescription");
        a.item("Properties", "Collection:PropertyEditorPropertyDescription:PropertyEditorPropertyDescriptionCollection:PropertyEditorPropertyDescription");
        a.item("FilterPlaceholderText", "String");
        a.item("SearchInputType", "ExportedType:string:InputGroupDisplayType");
        a.item("SearchInputType@names", "Line;Box;Border;Search");
        a.item("RowHeight", "Number:int");
        a.item("CellFontFamily", "(w:CellFontFamily/FontFamilyTransform,xam:CellFontFamily,wf:CellFontFamily,web:cellTextStyle/FontFamilyTransform)String");
        a.item("CellFontSize", "(w:CellFontSize,xam:CellFontSize,wf:CellFontSize,web:cellTextStyle/FontSizeTransform)Number:double");
        a.item("CellFontStyle", "(w:CellFontStyle/FontStyleTransform,xam:CellFontFamily/FontStyleTransform,wf:CellFontFamily/FontStyleTransform,web:cellTextStyle/FontStyleTransform)String");
        a.item("CellFontWeight", "(w:CellFontWeight/FontWeightTransform,xam:CellFontFamily/FontWeightTransform,wf:CellFontFamily/FontWeightTransform,web:cellTextStyle/FontWeightTransform)String");
        a.item("BaseTheme", "ExportedType:string:BaseControlTheme");
        a.item("BaseTheme@names", "Default;DenaliLight;MaterialLight");
        a.item("Density", "ExportedType:string:ControlDisplayDensity");
        a.item("Density@names", "Auto;Comfortable;Cosy;Compact");
        a.item("DescriptionContextRef", "(w:DescriptionContext,wf:DescriptionContext)DataRef::object");
        a.item("ComponentRendererRef", "(w:ComponentRenderer,wf:ComponentRenderer)DataRef::object");
        a.item("TargetRef", "(w:Target,wf:Target)DataRef::object");
        a.item("DescriptionType", "String");
        a.item("IsHorizontal", "Boolean");
        a.item("IsWrappingEnabled", "Boolean");
        a.item("IsIndirectModeEnabled", "Boolean");
        a.item("BackgroundColor", "Brush");
        a.item("TextColor", "Brush");
        PropertyEditorDescriptionMetadata.e(a);
    };
    PropertyEditorDescriptionMetadata.d = function (a) {
        PropertyEditorDescriptionMetadata.b(a);
        a.aa("PropertyEditor", function () { return new PropertyEditorDescription(); });
        a.z("PropertyEditor", PropertyEditorDescriptionMetadata.a);
    };
    PropertyEditorDescriptionMetadata.e = function (a) {
        a.item("_qualifiedName", "String:Infragistics.Controls.Grids.XamPropertyEditor");
        a.item("Width", "(w:Width/DimensionTransform,xam:Width/DimensionTransform)String");
        a.item("Height", "(w:Height/DimensionTransform,xam:Height/DimensionTransform)String");
        a.item("Background", "(wf:BackColor/ColorTransform)Brush");
    };
    PropertyEditorDescriptionMetadata.$t = markType(PropertyEditorDescriptionMetadata, 'PropertyEditorDescriptionMetadata');
    PropertyEditorDescriptionMetadata.a = null;
    return PropertyEditorDescriptionMetadata;
}(Base));
export { PropertyEditorDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/PropertyEditorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyEditorDescription } from "./PropertyEditorDescription";
/**
 * @hidden
 */
var PropertyEditorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(PropertyEditorDescriptionMetadata, _super);
    function PropertyEditorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PropertyEditorDescriptionMetadata.b = function (a) {
        if (PropertyEditorDescriptionMetadata.a == null) {
            PropertyEditorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PropertyEditorDescriptionMetadata.c(PropertyEditorDescriptionMetadata.a);
        }
        if (a.k(PropertyEditorDescriptionMetadata.a)) {
            return;
        }
        a.aa(PropertyEditorDescriptionMetadata.a);
    };
    PropertyEditorDescriptionMetadata.c = function (a) {
        a.item("ActualDataSource", "(w:ActualProperties,xam:ActualProperties,wf:ActualProperties)Collection:PropertyEditorPropertyDescription:PropertyEditorPropertyDescriptionCollection:PropertyEditorPropertyDescription");
        a.item("Properties", "Collection:PropertyEditorPropertyDescription:PropertyEditorPropertyDescriptionCollection:PropertyEditorPropertyDescription");
        a.item("FilterPlaceholderText", "String");
        a.item("SearchInputType", "ExportedType:string:InputGroupDisplayType");
        a.item("SearchInputType@names", "Line;Box;Border;Search");
        a.item("RowHeight", "Number:int");
        a.item("CellFontFamily", "(w:CellFontFamily/FontFamilyTransform,xam:CellFontFamily,wf:CellFontFamily,web:cellTextStyle/FontFamilyTransform)String");
        a.item("CellFontSize", "(w:CellFontSize,xam:CellFontSize,wf:CellFontSize,web:cellTextStyle/FontSizeTransform)Number:double");
        a.item("CellFontStyle", "(w:CellFontStyle/FontStyleTransform,xam:CellFontFamily/FontStyleTransform,wf:CellFontFamily/FontStyleTransform,web:cellTextStyle/FontStyleTransform)String");
        a.item("CellFontWeight", "(w:CellFontWeight/FontWeightTransform,xam:CellFontFamily/FontWeightTransform,wf:CellFontFamily/FontWeightTransform,web:cellTextStyle/FontWeightTransform)String");
        a.item("BaseTheme", "ExportedType:string:BaseControlTheme");
        a.item("BaseTheme@names", "Default;DenaliLight;MaterialLight");
        a.item("Density", "ExportedType:string:ControlDisplayDensity");
        a.item("Density@names", "Auto;Comfortable;Cosy;Compact");
        a.item("DescriptionContextRef", "(w:DescriptionContext,wf:DescriptionContext)DataRef::object");
        a.item("ComponentRendererRef", "(w:ComponentRenderer,wf:ComponentRenderer)DataRef::object");
        a.item("TargetRef", "(w:Target,wf:Target)DataRef::object");
        a.item("DescriptionType", "String");
        a.item("IsHorizontal", "Boolean");
        a.item("IsWrappingEnabled", "Boolean");
        a.item("IsIndirectModeEnabled", "Boolean");
        a.item("BackgroundColor", "Brush");
        a.item("TextColor", "Brush");
        PropertyEditorDescriptionMetadata.e(a);
    };
    PropertyEditorDescriptionMetadata.d = function (a) {
        PropertyEditorDescriptionMetadata.b(a);
        a.ac("PropertyEditor", function () { return new PropertyEditorDescription(); });
        a.ab("PropertyEditor", PropertyEditorDescriptionMetadata.a);
    };
    PropertyEditorDescriptionMetadata.e = function (a) {
        a.item("_qualifiedName", "String:Infragistics.Controls.Grids.XamPropertyEditor");
        a.item("Width", "(w:Width/DimensionTransform,xam:Width/DimensionTransform)String");
        a.item("Height", "(w:Height/DimensionTransform,xam:Height/DimensionTransform)String");
        a.item("Background", "(wf:BackColor/ColorTransform)Brush");
    };
    PropertyEditorDescriptionMetadata.$t = markType(PropertyEditorDescriptionMetadata, 'PropertyEditorDescriptionMetadata');
    PropertyEditorDescriptionMetadata.a = null;
    return PropertyEditorDescriptionMetadata;
}(Base));
export { PropertyEditorDescriptionMetadata };
